==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/LinksCancel.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksCancelCancel;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksCancel
 */
@JsonPropertyOrder({ LinksCancel.JSON_PROPERTY_CANCEL })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksCancel implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CANCEL = "cancel";
    private LinksCancelCancel cancel;

    public LinksCancel() {
    }

    public LinksCancel cancel(LinksCancelCancel cancel) {

        this.cancel = cancel;
        return this;
    }

    /**
     * Get cancel
     *
     * @return cancel
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CANCEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksCancelCancel getCancel() {
        return cancel;
    }

    @JsonProperty(JSON_PROPERTY_CANCEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCancel(LinksCancelCancel cancel) {
        this.cancel = cancel;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksCancel linksCancel = (LinksCancel) o;
        return Objects.equals(this.cancel, linksCancel.cancel);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(cancel);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksCancel {\n");
        sb.append("    cancel: ").append(toIndentedString(cancel)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/LinksCancel.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksCancelCancel;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksCancel
 */
@JsonPropertyOrder({ LinksCancel.JSON_PROPERTY_CANCEL })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class LinksCancel implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CANCEL = "cancel";
    private LinksCancelCancel cancel;

    public LinksCancel() {
    }

    public LinksCancel cancel(LinksCancelCancel cancel) {

        this.cancel = cancel;
        return this;
    }

    /**
     * Get cancel
     *
     * @return cancel
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CANCEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksCancelCancel getCancel() {
        return cancel;
    }

    @JsonProperty(JSON_PROPERTY_CANCEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCancel(LinksCancelCancel cancel) {
        this.cancel = cancel;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksCancel linksCancel = (LinksCancel) o;
        return Objects.equals(this.cancel, linksCancel.cancel);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(cancel);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksCancel {\n");
        sb.append("    cancel: ").append(toIndentedString(cancel)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
